@@ -1,4 +1,4 @@
-import net
+from cerberuspackage1.adaface import net
 import torch
 import os
 import numpy as np
